componenttools.get_most_distant_sequential_container_in_improper_parentage_of_component
=======================================================================================

.. autofunction:: abjad.tools.componenttools.get_most_distant_sequential_container_in_improper_parentage_of_component.get_most_distant_sequential_container_in_improper_parentage_of_component
   :noindex:
